@@ -2,6 +2,15 @@ import datetime
 import platform
 from LibHanger.Library.uwGlobals import *
 
+class datetimeFormat():
+    
+    """
+    日付書式
+    """
+    
+    yyyyMMddhhmmss = '%Y%m%d%H%M%S'
+    """ yyyyMMddhhmmss"""
+
 def getPlatform():
 
     """ 
@@ -23,18 +32,26 @@ def getPlatform():
     elif pf == 'Linux':
         return gv.platForm.linux
 
-def getNow():
+def getNow(fmt:str=''):
 
     """ 
     現在日時取得
     
     Parameters
     ----------
-    none
+    fmt : str
+        変換する日付書式
     """
-
+    
     # 日本時刻取得
-    return datetime.datetime.now(datetime.timezone(datetime.timedelta(hours=9))) 
+    nowDateTime = datetime.datetime.now(datetime.timezone(datetime.timedelta(hours=9)))
+    if fmt == '':
+        return nowDateTime
+    elif datetimeFormat.yyyyMMddhhmmss == fmt:
+        # yyyyMMddhhmmss形式に変換
+        return nowDateTime.strftime(fmt)
+    else:
+        return nowDateTime    
 
 def addDays(targetDate, addDays: int):
     
