@@ -2,7 +2,7 @@ import logging
 import os
 from .uwConfig import cmnConfig
 
-def loggerDecorator(outputString):
+def loggerDecorator(outputString, args_print = []):
 
     """
     関数の開始～終了でコンソールに文字列を出力するデコレーター
@@ -19,22 +19,42 @@ def loggerDecorator(outputString):
             """
             デコレーターのラッパー
             """
+            
+            # 関数名の出力
+            funcName = '({0}) ... Execute'.format(outputString)
+            print(funcName)
+            logging.info(funcName)
+
+            # 引数の出力
+            if len(args_print) > 0 and len(kwargs) > 0:
+                for argsStr in args_print:
+                    if kwargs.get(argsStr) == None : continue
+                    argsValue = 'args:{0}={1}'.format(str(argsStr), str(kwargs.get(argsStr)))
+                    print(argsValue)
+                    logging.info(argsValue)
 
-            print('(' + outputString + ') ...', end = '')
-            logging.info('(' + outputString + ') ...')
             try:
+                # 関数本体の実行
                 ret = func(*args, **kwargs)
-                print('OK')
-                logging.info('OK')
+                
+                # 実行終了の出力
+                funcEnded = '({0}) ... OK'.format(outputString)
+                print(funcEnded)
+                logging.info(funcEnded)
+
             except Exception as e:
-                errorInfo = 'NG\n'\
+                
+                # 例外時エラーメッセージ
+                errorInfo = '(' + outputString + ') ... ' + 'NG\n'\
                             '=== エラー内容 ===\n'\
                             'type:' + str(type(e)) + '\n'\
                             'args:' + str(e.args) + '\n'\
                             'e自身:' + str(e)
 
+                # エラーメッセージの出力
                 print(errorInfo)
                 logging.error(errorInfo)
+
                 return
             return ret
 
