@@ -44,12 +44,15 @@ class modelGenerator(ExcelImporter):
         
         """
         
+        # テーブル一覧リスト取得
+        dfTableList = self.get_TableListByDataFrame('テーブル一覧表')
+
         for sheetname in self.sheets:
             if str(sheetname).startswith(('trn','mst')): 
                 # テーブル定義をDataFrameで取得
-                df = self.get_TableDefByDataFrame(sheetname)
+                dfDef = self.get_TableDefByDataFrame(sheetname)
                 # Model内容をpythonファイル出力
-                self.put_modelPython(df, sheetname)
+                self.put_modelPython(dfDef, dfTableList, sheetname)
     
     def put_modelToSql(self):
         
@@ -98,7 +101,7 @@ class modelGenerator(ExcelImporter):
         # DataFrameとして返す
         return df
     
-    def put_modelPython(self, df:DataFrame, sheetname:str):
+    def put_modelPython(self, dfDef:DataFrame, dfTableList, sheetname:str):
         
         """
         ModelをPythonファイルに出力
@@ -111,9 +114,15 @@ class modelGenerator(ExcelImporter):
             読込対象シート名
         """
         
+        # スキーマ取得
+        dfSchema = dfTableList[dfTableList['tablename'] == sheetname]
+        schema = ''
+        if len(dfSchema) > 0:
+            schema = dfSchema.iloc[0]['schema']
+            
         # 出力先パス取得
         output_dir = os.path.dirname(self.filepath)
-        
+
         # pythonファイル出力
         with open(os.path.join(output_dir, sheetname + '.py'), 'w', newline='', encoding='utf-8') as f:
             f.writelines('import LibHanger.Models.fields as fld\n')
@@ -128,14 +137,17 @@ class modelGenerator(ExcelImporter):
             f.writelines('\t' + '# テーブル名\n')
             f.writelines('\t' + '__tablename__ = \'{0}\''.format(sheetname) + '\n')
             f.writelines('\t\n')
+            f.writelines('\t' + '# スキーマ\n')
+            f.writelines('\t' + '__table_args__ = {' + '\'schema\': \'{0}\''.format(schema) + '}' + '\n')
+            f.writelines('\t\n')
             f.writelines('\t' + '# 列定義\n')
-            for index, row in df.iterrows():
+            for index, row in dfDef.iterrows():
                 print('LineNo={0}'.format(index))
-                outputRow = '\t'  + '{0} = fld.{1}({2})'.format(row['fieldname'],self.get_fieldType_val(row, 'method'), self.get_fieldType_args(row)) + '\n'
+                outputRow = '\t'  + '{0} = fld.{1}({2})'.format(row['fieldname'],self.get_columnTypeByModel(row, 'method'), self.get_fieldType_args(row)) + '\n'
                 f.writelines(outputRow)
         f.close()
         
-    def get_fieldType_val(self, defRow, valType):
+    def get_columnTypeByModel(self, defRow, valType):
         
         """
         テーブル定義のデータ型に対応するColumnType取得
@@ -151,7 +163,7 @@ class modelGenerator(ExcelImporter):
         fieldTypeVal:dict = self.fieldTypeMapPy.get(defRow['datatype'])
         return fieldTypeVal.get(valType)
         
-    def get_fieldType_val(self, defRow):
+    def get_columnTypeBySql(self, defRow):
         
         """
         テーブル定義のデータ型に対応するColumnType取得
@@ -160,8 +172,6 @@ class modelGenerator(ExcelImporter):
         ----------
         defRow : Any
             対象Series
-        valType : Any
-            データ型
         """
         
         # 桁数指定があるかどうか
@@ -282,14 +292,16 @@ class modelGenerator(ExcelImporter):
         
         # SQLファイル出力
         with open(os.path.join(output_dir, sheetname + '.sql'), 'w', newline='', encoding='utf-8') as f:
-            f.writelines('create table {0}.{1} ('.format(schema, sheetname) + '\n')
+            f.writelines('drop table if exists {0}.{1}; \n'.format(schema, sheetname))           
+            f.writelines('\n')
+            f.writelines('create table {0}.{1} ( \n'.format(schema, sheetname))
             for index, row in dfDef.iterrows():
                 print('LineNo={0}'.format(index))
                 comma = ' '
                 if index > 0:
                     comma = ','
-                outputRow = '\t{0}{1}\t{2}'.format(comma, str(row['fieldname']), self.get_fieldType_val(row))
+                outputRow = '\t{0}{1}\t{2}'.format(comma, str(row['fieldname']), self.get_columnTypeBySql(row))
                 f.writelines(outputRow)
-            f.writelines('\t' + ',PRIMARY KEY({0})'.format(','.join(primary_key)) + '\n')
-            f.writelines(');' + '\n')
+            f.writelines('\t' + ',PRIMARY KEY({0}) \n'.format(','.join(primary_key)))
+            f.writelines('); \n')
         f.close()
\ No newline at end of file
