@@ -8,7 +8,7 @@ class recset():
     レコードセットクラス
     """
     
-    def __init__(self, t) -> None:
+    def __init__(self, t, __session = None) -> None:
         
         """
         コンストラクタ
@@ -17,6 +17,8 @@ class recset():
         ----------
         t : Any
             Modelクラス
+        __session : Any
+            DBセッション
         """
         
         # Modelクラス
@@ -30,6 +32,18 @@ class recset():
         
         # 主キー情報
         self.__primaryKeys = self.__getPrimaryKeys()
+
+        # DBセッション保持
+        self.__session = __session
+    
+    @property
+    def session(self):
+        
+        """
+        DBセッション
+        """
+        
+        return self.__session
     
     def __getColumnAttr(self):
         
@@ -178,4 +192,19 @@ class recset():
             df = df.set_index(self.__primaryKeys, drop=False)
                 
         # 戻り値を返す
-        return df
\ No newline at end of file
+        return df
+    
+    def filter(self, w):
+        
+        """
+        レコードセットをフィルタする
+
+        Parameters
+        ----------
+        w : any
+            where条件
+        """
+        q = self.__session.query(self.modelType).filter(w).all()
+        for row in q:
+            self.rows.append(row)
+        #return self.__session.query(self.modelType).filter(w).all()
\ No newline at end of file
